@@ -1,14 +1,7 @@
 import typing
 from pathlib import Path
-import n0struct
 from .n0struct_n0list_n0dict import n0dict
-from .n0struct_logging import (
-    n0print,
-    n0debug,
-    n0debug_calc,
-    n0error,
-    set_debug_show_object_type,
-)
+from .n0struct_n0list_n0dict import n0list
 # ******************************************************************************
 # ******************************************************************************
 def parse_complex_csv_line(
@@ -228,9 +221,9 @@ def generate_csv(root_node:dict, list_xpath:str, mapping_dict:dict = None, save_
 
         for found_item in list_of_items:  # found_item == row in case of CSV list or item node in case of XML structure
             if isinstance(found_item, dict):
-                found_item = n0struct.n0dict(found_item) # to have ability to use .first(xpath)
+                found_item = n0dict(found_item) # to have ability to use .first(xpath)
             elif isinstance(found_item, list):
-                found_item = n0struct.n0list(found_item) # to have ability to use .first(xpath)
+                found_item = n0list(found_item) # to have ability to use .first(xpath)
 
             csv_row = []
             for column_name in mapping_dict:
@@ -377,34 +370,23 @@ def validate_csv_row(
 
         for validation in column_schema.get('validations', ()):
             validation_msg = None
-            n0debug("validation")
             if isinstance(validation, (list,tuple)):
                 validation_lambda = validation[0]
                 if len(validation) >= 2:
                     validation_msg = validation[1]
             else:
                 validation_lambda = validation
-            n0debug("validation_lambda")
-            n0debug("validation_msg")
 
             is_valid = False
             try:
                 lambda_function_for_validation = eval("lambda column_value, row: " + validation_lambda.format(**mapped_values))
             except Exception as ex1:
                 validation_msg = f"Not passed validation #1 for '{column_name}': " + str(ex1)
-                n0error(f"{validation_lambda=}")
-                n0error(f"{ex1=}")
             else:
                 try:
                     is_valid = lambda_function_for_validation(column_value, row)
                 except Exception as ex2:
                     validation_msg = f"Not passed validation #2 for '{column_name}': " + str(ex2)
-                    set_debug_show_object_type(True)
-                    n0debug("external_variables")
-                    n0error(f"{validation_lambda=}")
-                    n0error(f"{column_value=}")
-                    n0error(f"{row=}")
-                    n0error(f"{ex2=}")
             finally:
                 if is_valid == False:
                     if column_name not in failed_validations:
@@ -414,14 +396,6 @@ def validate_csv_row(
                         failed_validation_message = validation_msg.format(**mapped_values)
                     except Exception as ex3:
                         failed_validation_message = f"Not passed validation #3 for '{column_name}': " + str(ex3)
-                        set_debug_show_object_type(True)
-                        n0debug("external_variables")
-                        n0error(f"{validation_lambda=}")
-                        n0error(f"{column_value=}")
-                        n0error(f"{row=}")
-                        n0error(f"{validation_msg=}")
-                        n0error(f"{mapped_values=}")
-                        n0error(f"{ex3=}")
 
                     finally:
                         failed_validations[column_name].append(failed_validation_message)
