@@ -4,7 +4,6 @@ from .n0struct_utils_find import split_name_index
 from .n0struct_findall import findall as n0struct_findall__findall
 from .n0struct_findall import findfirst as n0struct_findall__findfirst
 from .n0struct_files import n0eval
-from .n0struct_logging import *
 # ******************************************************************************
 # ******************************************************************************
 class n0dict__(dict):
@@ -24,7 +23,7 @@ class n0dict__(dict):
         If any of [where1][where2]...[whereN] are not found, exception IndexError will be raised
         """
         if not xpath:
-            raise Exception("xpath '%s' is not valid" % str(xpath))
+            raise IndexError("xpath '%s' is not valid" % str(xpath))
         if xpath.startswith('?'):
             xpath = xpath[1:]
             raise_exception = False
@@ -129,15 +128,15 @@ class n0dict__(dict):
             node_name, node_index = split_name_index(node_name_index)
             if isinstance(parent_node, dict):
                 if node_index:
-                    raise Exception("How is it possible: index '%s' for dictionary (%s)'%s'?"% (node_index, type(parent_node), parent_node))
+                    raise IndexError("How is it possible: index '%s' for dictionary (%s)'%s'?"% (node_index, type(parent_node), parent_node))
                 parent_node.update({node_name_index: new_value})
             elif isinstance(parent_node, (list, tuple)):
                 if node_name:
-                    raise Exception("How is it possible: key '%s' for list (%s)'%s'?" % (node_name, type(parent_node), parent_node))
+                    raise IndexError("How is it possible: key '%s' for list (%s)'%s'?" % (node_name, type(parent_node), parent_node))
                 eval_node_index = n0eval(node_index)
                 parent_node[n0eval(node_index)] = new_value
             else:
-                raise Exception("How is it possible: unknown type of parent node (%s) of '%s'" % (type(parent_node), parent_node))
+                raise TypeError("How is it possible: unknown type of parent node (%s) of '%s'" % (type(parent_node), parent_node))
         else:
             super(n0dict__, self).__setitem__(xpath, new_value)
 
@@ -152,13 +151,10 @@ class n0dict__(dict):
                 recursively and
                 isinstance(cur_value, n0dict__) and not len(cur_value)
             ):
-                # n0debug("parent_node")
-                # n0debug("node_name_index")
                 if isinstance(parent_node, list) and not isinstance(node_name_index, int):
                     if not isinstance(node_name_index, str) or not node_name_index.startswith('[') or not node_name_index.endswith(']'):
-                        raise Exception(f"Not expactable index for list {node_name_index}")
+                        raise IndexError(f"Not expactable index for list {node_name_index}")
                     node_name_index = n0eval(node_name_index[1:-1])
-                    # n0debug("node_name_index")
                 del parent_node[node_name_index]
         return self
     # **************************************************************************
@@ -260,7 +256,7 @@ class n0dict__(dict):
                 else:
                     self[key].append(itm)
         else:
-            raise Exception("Unexpected type of other: " + str(type(other)))
+            raise TypeError("Unexpected type of other: " + str(type(other)))
         return self
     # **************************************************************************
     # **************************************************************************
